@@ -39,10 +39,15 @@ main8 = main(8)
 
 
 B10 = {r'': "0123456789"}
-base(B10, r"^(?:base[-_]?10|int(?:eger)?)$")
+base(B10, r"^(?:base[-_]?10|int(?:eger)?|dec(?:imal)?)$")
 main10 = main(10)
 
 
+B11 = {r'': "0123456789a", r'[-_]inv(erted)?$': "a0123456789"}
+base(B11, r"^base[-_]?11(|[-_]inv(?:erted)?)$")
+main11 = main(11)
+
+
 B16 = {'': digits + "ABCDEF", '[-_]inv(erted)?$': "ABCDEF" + digits}
 base2n(B16, r"^(?:base[-_]?16|hex)(|[-_]inv(?:erted)?)$", expansion_factor=2.)
 main16 = main(16, "RFC 4648")
